@@ -21,12 +21,20 @@
 
 #include <qtest.h>
 
-#include "kimap2test/fakeserver.h"
-#include "kimap2/session.h"
-#include "kimap2/loginjob.h"
+#include "kimaptest/fakeserver.h"
+#include "kimap/session.h"
+#include "kimap/loginjob.h"
 
 #include <QtTest>
 
+class TestUiProxy: public KIMAP::SessionUiProxy
+{
+    virtual bool ignoreSslError(const KSslErrorUiData &)
+    {
+        return true;
+    }
+};
+
 class LoginJobTest: public QObject
 {
     Q_OBJECT
@@ -41,28 +49,22 @@ private Q_SLOTS:
 
         QList<QByteArray> scenario;
         scenario << FakeServer::greeting()
-                 << "C: A000001 CAPABILITY"
-                 << "S: A000001 OK"
-                 << "C: A000002 LOGIN \"user\" \"password\""
-                 << "S: A000002 OK User logged in";
+                 << "C: A000001 LOGIN \"user\" \"password\""
+                 << "S: A000001 OK User logged in";
 
         QTest::newRow("success") << "user" << "password" << scenario;
 
         scenario.clear();
         scenario << FakeServer::greeting()
-                 << "C: A000001 CAPABILITY"
-                 << "S: A000001 OK"
-                 << "C: A000002 LOGIN \"user_bad\" \"password\""
-                 << "S: A000002 NO Login failed: authentication failure";
+                 << "C: A000001 LOGIN \"user_bad\" \"password\""
+                 << "S: A000001 NO Login failed: authentication failure";
 
         QTest::newRow("wrong login") << "user_bad" << "password" << scenario;
 
         scenario.clear();
         scenario << FakeServer::greeting()
-                 << "C: A000001 CAPABILITY"
-                 << "S: A000001 OK"
-                 << "C: A000002 LOGIN \"user\" \"aa\\\"bb\\\\cc[dd ee\""
-                 << "S: A000002 OK User logged in";
+                 << "C: A000001 LOGIN \"user\" \"aa\\\"bb\\\\cc[dd ee\""
+                 << "S: A000001 OK User logged in";
 
         QTest::newRow("special chars") << "user" << "aa\"bb\\cc[dd ee" << scenario;
 
@@ -82,9 +84,9 @@ private Q_SLOTS:
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP2::Session *session = new KIMAP2::Session("127.0.0.1", 5989);
+        KIMAP::Session *session = new KIMAP::Session("127.0.0.1", 5989);
 
-        KIMAP2::LoginJob *login = new KIMAP2::LoginJob(session);
+        KIMAP::LoginJob *login = new KIMAP::LoginJob(session);
         login->setUserName(user);
         login->setPassword(password);
         bool result = login->exec();
@@ -106,12 +108,10 @@ private Q_SLOTS:
 
         QList<QByteArray> scenario;
         scenario << FakeServer::greeting()
-                 << "C: A000001 CAPABILITY"
-                 << "S: A000001 OK"
-                 << "C: A000002 AUTHENTICATE PLAIN"
-                 << "S: A000002 OK (success)"
-                 << "C: A000003 LOGIN \"proxy\" \"user\" \"password\""
-                 << "S: A000003 OK User logged in";
+                 << "C: A000001 AUTHENTICATE PLAIN"
+                 << "S: A000001 OK (success)"
+                 << "C: A000001 LOGIN \"proxy\" \"user\" \"password\""
+                 << "S: A000001 OK User logged in";
 
         QTest::newRow("success") << "user" << "proxy" << "password" << scenario;
     }
@@ -127,10 +127,10 @@ private Q_SLOTS:
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP2::Session *session = new KIMAP2::Session("127.0.0.1", 5989);
+        KIMAP::Session *session = new KIMAP::Session("127.0.0.1", 5989);
 
-        KIMAP2::LoginJob *login = new KIMAP2::LoginJob(session);
-        login->setAuthenticationMode(KIMAP2::LoginJob::Plain);
+        KIMAP::LoginJob *login = new KIMAP::LoginJob(session);
+        login->setAuthenticationMode(KIMAP::LoginJob::Plain);
         login->setUserName(user);
         login->setAuthorizationName(proxy);
         login->setPassword(password);
@@ -149,37 +149,29 @@ private Q_SLOTS:
 
         QList<QByteArray> scenario;
         scenario << FakeServer::greeting()
-                 << "C: A000001 CAPABILITY"
-                 << "S: A000001 OK"
-                 << "C: A000002 LOGIN \"user\" \"password\""
-                 << "S: A000002 OK Welcome John Smith";
+                 << "C: A000001 LOGIN \"user\" \"password\""
+                 << "S: A000001 OK Welcome John Smith";
 
         QTest::newRow("greeting") << "Welcome John Smith" << scenario;
 
         scenario.clear();
         scenario << FakeServer::greeting()
-                 << "C: A000001 CAPABILITY"
-                 << "S: A000001 OK"
-                 << "C: A000002 LOGIN \"user\" \"password\""
-                 << "S: A000002 OK Welcome John Smith (last login: Feb 21, 2010)";
+                 << "C: A000001 LOGIN \"user\" \"password\""
+                 << "S: A000001 OK Welcome John Smith (last login: Feb 21, 2010)";
 
         QTest::newRow("greeting with parenthesis") << "Welcome John Smith (last login: Feb 21, 2010)" << scenario;
 
         scenario.clear();
         scenario << FakeServer::greeting()
-                 << "C: A000001 CAPABILITY"
-                 << "S: A000001 OK"
-                 << "C: A000002 LOGIN \"user\" \"password\""
-                 << "S: A000002 OK";
+                 << "C: A000001 LOGIN \"user\" \"password\""
+                 << "S: A000001 OK";
 
         QTest::newRow("no greeting") << "" << scenario;
 
         scenario.clear();
         scenario << FakeServer::greeting()
-                 << "C: A000001 CAPABILITY"
-                 << "S: A000001 OK"
-                 << "C: A000002 LOGIN \"user\" \"password\""
-                 << "S: A000002 NO Login failed: authentication failure";
+                 << "C: A000001 LOGIN \"user\" \"password\""
+                 << "S: A000001 NO Login failed: authentication failure";
 
         QTest::newRow("login failed") << "" << scenario;
     }
@@ -193,9 +185,9 @@ private Q_SLOTS:
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP2::Session *session = new KIMAP2::Session("127.0.0.1", 5989);
+        KIMAP::Session *session = new KIMAP::Session("127.0.0.1", 5989);
 
-        KIMAP2::LoginJob *login = new KIMAP2::LoginJob(session);
+        KIMAP::LoginJob *login = new KIMAP::LoginJob(session);
         login->setUserName("user");
         login->setPassword("password");
         login->exec();
@@ -211,7 +203,6 @@ private Q_SLOTS:
         QTest::addColumn< QList<QByteArray> >("scenario");
         QTest::addColumn< int >("serverEncryption");
         QTest::addColumn< int >("clientEncryption");
-        QTest::addColumn< bool >("startTls");
 
         {
             QList<QByteArray> scenario;
@@ -223,9 +214,8 @@ private Q_SLOTS:
                      << "C: A000003 LOGIN \"user\" \"password\""
                      << "S: A000003 OK";
 
-            QTest::newRow("starttls tlsv1.0") << scenario << static_cast<int>(QSsl::TlsV1_0) << static_cast<int>(QSsl::TlsV1_0) << true;
-            QTest::newRow("starttls tlsv1.1") << scenario << static_cast<int>(QSsl::TlsV1_1) << static_cast<int>(QSsl::TlsV1_1) << true;
-            QTest::newRow("starttls tlsv1.2") << scenario << static_cast<int>(QSsl::TlsV1_2) << static_cast<int>(QSsl::TlsV1_2) << true;
+            //KIMAP ties tlsv1 to starttls
+            QTest::newRow("tlsv1") << scenario << static_cast<int>(QSsl::TlsV1) << static_cast<int>(KIMAP::LoginJob::TlsV1);
         }
         {
             QList<QByteArray> scenario;
@@ -235,12 +225,12 @@ private Q_SLOTS:
                      << "C: A000002 LOGIN \"user\" \"password\""
                      << "S: A000002 OK";
 
-            QTest::newRow("sslv3") << scenario << static_cast<int>(QSsl::SslV3) << static_cast<int>(QSsl::SslV3) << false;
-            //sslv2 is not supported anymore on my system
-            // QTest::newRow("sslv2") << scenario << static_cast<int>(QSsl::SslV2) << static_cast<int>(KIMAP2::LoginJob::SslV2);
-            //AnyProtocol doesn't mean the server can force a specific version (e.g. openssl always starts with a sslv2 hello)
-            QTest::newRow("any protocol with anyssl version") << scenario << static_cast<int>(QSsl::AnyProtocol) << static_cast<int>(QSsl::AnyProtocol) << false;
-            QTest::newRow("tlsv1.0") << scenario << static_cast<int>(QSsl::TlsV1_0) << static_cast<int>(QSsl::TlsV1_0) << false;
+            QTest::newRow("sslv3") << scenario << static_cast<int>(QSsl::SslV3) << static_cast<int>(KIMAP::LoginJob::SslV3);
+            QTest::newRow("sslv2") << scenario << static_cast<int>(QSsl::SslV2) << static_cast<int>(KIMAP::LoginJob::SslV2);
+            //AnySslVersion doesn't mean the server can force a specific version (e.g. openssl always starts with a sslv2 hello)
+            QTest::newRow("any protocol with anyssl version") << scenario << static_cast<int>(QSsl::AnyProtocol) << static_cast<int>(KIMAP::LoginJob::AnySslVersion);
+            //KIMAP and KTcpSocket use SslV3_1 but really mean tls without starttls
+            QTest::newRow("sslv3_1") << scenario << static_cast<int>(QSsl::TlsV1SslV3) << static_cast<int>(KIMAP::LoginJob::SslV3_1);
         }
     }
 
@@ -249,24 +239,21 @@ private Q_SLOTS:
         QFETCH(QList<QByteArray>, scenario);
         QFETCH(int, serverEncryption);
         QFETCH(int, clientEncryption);
-        QFETCH(bool, startTls);
 
         FakeServer fakeServer;
-        fakeServer.setEncrypted(static_cast<QSsl::SslProtocol>(serverEncryption), startTls);
+        fakeServer.setEncrypted(static_cast<QSsl::SslProtocol>(serverEncryption));
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP2::Session *session = new KIMAP2::Session("127.0.0.1", 5989);
+        KIMAP::Session *session = new KIMAP::Session("127.0.0.1", 5989);
 
-        QObject::connect(session, &KIMAP2::Session::sslErrors, [session](const QList<QSslError> &errors) {
-            qWarning() << "Got ssl error: " << errors;
-            session->ignoreErrors(errors);
-        });
+        KIMAP::SessionUiProxy::Ptr uiProxy(new TestUiProxy);
+        session->setUiProxy(uiProxy);
 
-        KIMAP2::LoginJob *login = new KIMAP2::LoginJob(session);
+        KIMAP::LoginJob *login = new KIMAP::LoginJob(session);
         login->setUserName("user");
         login->setPassword("password");
-        login->setEncryptionMode(static_cast<QSsl::SslProtocol>(clientEncryption), startTls);
+        login->setEncryptionMode(static_cast<KIMAP::LoginJob::EncryptionMode>(clientEncryption));
         QVERIFY(login->exec());
 
         fakeServer.quit();
@@ -285,8 +272,8 @@ private Q_SLOTS:
             scenario << FakeServer::greeting();
 
             //For some reason only connecting to tlsv1 results in an ssl handshake error, with the wrong version only the server detects the error and disconnects
-//     QTest::newRow( "ssl v3 v2" ) << scenario << static_cast<int>(QSsl::SslV3) << static_cast<int>(KIMAP2::LoginJob::SslV2) << static_cast<int>(KJob::UserDefinedError);
-            QTest::newRow("ssl tlsv1 v3") << scenario << static_cast<int>(QSsl::SslV3) << static_cast<int>(QSsl::TlsV1_0) << static_cast<int>(KIMAP2::SslHandshakeFailed);
+//     QTest::newRow( "ssl v3 v2" ) << scenario << static_cast<int>(QSsl::SslV3) << static_cast<int>(KIMAP::LoginJob::SslV2) << static_cast<int>(KJob::UserDefinedError);
+            QTest::newRow("ssl tlsv1 v3") << scenario << static_cast<int>(QSsl::TlsV1) << static_cast<int>(KIMAP::LoginJob::SslV3) << static_cast<int>(KJob::UserDefinedError);
         }
     }
 
@@ -294,25 +281,23 @@ private Q_SLOTS:
     {
         QFETCH(QList<QByteArray>, scenario);
         QFETCH(int, serverEncryption);
-        Q_UNUSED(serverEncryption);
         QFETCH(int, clientEncryption);
         QFETCH(int, expectedErrorCode);
 
         FakeServer fakeServer;
+        fakeServer.setEncrypted(static_cast<QSsl::SslProtocol>(serverEncryption));
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP2::Session *session = new KIMAP2::Session("127.0.0.1", 5989);
+        KIMAP::Session *session = new KIMAP::Session("127.0.0.1", 5989);
 
-        QObject::connect(session, &KIMAP2::Session::sslErrors, [session](const QList<QSslError> &errors) {
-            qWarning() << "Got ssl error: " << errors;
-            session->ignoreErrors(errors);
-        });
+        KIMAP::SessionUiProxy::Ptr uiProxy(new TestUiProxy);
+        session->setUiProxy(uiProxy);
 
-        KIMAP2::LoginJob *login = new KIMAP2::LoginJob(session);
+        KIMAP::LoginJob *login = new KIMAP::LoginJob(session);
         login->setUserName("user");
         login->setPassword("password");
-        login->setEncryptionMode(static_cast<QSsl::SslProtocol>(clientEncryption), false);
+        login->setEncryptionMode(static_cast<KIMAP::LoginJob::EncryptionMode>(clientEncryption));
         QVERIFY(!login->exec());
         QCOMPARE(static_cast<int>(login->error()), expectedErrorCode);
 
