@@ -38,10 +38,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include <QtCore/QTextCodec>
-#include <QtCore/QBuffer>
-#include <QtCore/QByteArray>
-#include <QtCore/QLatin1Char>
+#include <QTextCodec>
+#include <QBuffer>
+#include <QByteArray>
+#include <QLatin1Char>
 #include <kcodecs.h>
 
 using namespace KIMAP;
@@ -567,7 +567,7 @@ const QString KIMAP::encodeRFC2231String(const QString &str)
 
     signed char *latin = (signed char *)calloc(1, str.length() + 1);
     char *latin_us = (char *)latin;
-    strcpy(latin_us, str.toLatin1());
+    strcpy(latin_us, str.toLatin1().constData());
     signed char *l = latin;
     char hexcode;
     int i;
